icsemantic.catalog.tests.test_indexes

Package platecom :: Package ontocatalog :: Package tests :: Module test_indexes |
[hide private]
[frames] | no frames]

# Source Code for Module icsemantic.catalog.tests.test_indexes

     1  """Test the catalog indexes added by OntoCatalog.
     2  """
     3
     4  import unittest
     5  from platecom.ontocatalog.tests.base import OntoCatalogTestCase
     6
     7
     8 -class TestOntoCatalogIndexes(OntoCatalogTestCase):
     9      """Testing OntoCatalog indexes"""
    10
    11 -    def test_synonyms_index_search(self):
    12          """Test a catalog search using the SynonymIndex"""
    13          pass
    14
    15 -    def test_related_index_search(self):
    16          """Test a catalog search using the RelatedIndex"""
    17          pass
    18
    19 -    def test_translation_index_search(self):
    20          """Test a catalog search using the TranslationIndex"""
    21          pass
    22
    23
    24 -def test_suite():
    25      suite = unittest.TestSuite()
    26      suite.addTest(unittest.makeSuite(TestOntoCatalogIndexes))
    27      return suite
    28